@@ -34,7 +34,7 @@ use DynaLoader ();
 			 BAD_GATEWAY 
 			 HTTP_SERVICE_UNAVAILABLE
 			 VARIANT_ALSO_VARIES)],
-    common => [qw(OK DECLINED FORBIDDEN AUTH_REQUIRED SERVER_ERROR)],
+    common => [qw(OK DECLINED NOT_FOUND FORBIDDEN AUTH_REQUIRED SERVER_ERROR)],
 );
 
 @EXPORT = qw(
