@@ -13,6 +13,9 @@ $q->print(
    $q->end_form,
    "<p>textfield = ", $q->param("textfield"),
    $q->dump,
+   "<hr><pre>",
+   (map { "$_ = $ENV{$_}\n" } keys %ENV),	  
+   "</pre>",	  
    $q->end_html,
 );
 
